
// GetPage.java
// Andrew Davison, ad@fivedots.coe.psu.ac.th, Oct. 2022

/*
  > run GetPage elementsofcoordi00lone.pdf 100
  Executing GetPage elementsofcoordi00lone.pdf 100 with PDFBox and ImageJ...
  Extracting page 100...
  Image (w,h): (610, 965)
  Saved image to elementsofcoordi00lone-100.png
*/


import java.io.*;
import java.awt.image.BufferedImage;
import javax.imageio.ImageIO;


import org.apache.pdfbox.pdmodel.*;
import org.apache.pdfbox.pdmodel.common.*;
import org.apache.pdfbox.rendering.*;



public final class GetPage
{
  private static final int DPI_DEFAULT = 120;


  public static void main(String args[])
  {
    if (args.length != 2) {
      System.out.println("Usage: run WhitenPage <fnm> <pageNo>");
      System.exit(0);
    }

    String fnm = args[0];
    int pageIdx = Integer.parseInt(args[1]) - 1;
    
    try {
      PDDocument doc = PDDocument.load(new File(fnm));
      int lastPage = doc.getNumberOfPages();

      if ((pageIdx < 0) || (pageIdx >= lastPage)) {
        System.out.println("Page No. out of range: 1 - " + lastPage);
        System.exit(0);
      }

      System.out.println("Extracting page " + (pageIdx+1) + "...");
      PDFRenderer renderer = new PDFRenderer(doc);
      renderer.setSubsamplingAllowed(true);

      BufferedImage im = renderer.renderImageWithDPI(pageIdx, DPI_DEFAULT, ImageType.RGB);
      System.out.println("Image (w,h): (" + im.getWidth() + ", " + im.getHeight() + ")");

      // save image as PNG file
      String outFnm = stripExt(fnm) + "-" + (pageIdx+1) + ".png";
      saveImage(im, outFnm);
       
      doc.close();
    }
    catch(Exception e)
    {  System.out.println(e);  }

  }  // end of main()



  private static String stripExt(String fnm)
  {
    int dotPos = fnm.lastIndexOf('.');
    if (dotPos == -1)
      return fnm;
    else
      return fnm.substring(0, dotPos);
  }


  private static void saveImage(BufferedImage im, String fnm)
  {
    try {
      ImageIO.write(im, "png", new File(fnm));
      System.out.println("Saved image to " + fnm);
    }
    catch (Exception e) {
      System.out.println("Could not save image: " + e);
    }
  }

} // end  of GetPage class

